.. _ref-API-Utils:
.. currentmodule:: caterva2

Utility classes and variables
=============================

A collection of utility classes and variables that are used throughout the Caterva2 API.

.. automodule:: caterva2
    :members:
    :undoc-members:
    :exclude-members: Client, Root, Dataset, File

    .. autodata:: __version__
